@@ -61,6 +61,7 @@ def open_json(file_name):
 def update_json(data, json_file):
     json_file.seek(0)
     json.dump(data, json_file, indent=4)
+    json_file.truncate()
     json_file.close()
 
 
@@ -148,24 +149,23 @@ def add_files(arg):
     if not check_if_file_exists(GIT_JSON_NAME):
         return
     json_obj, json_file = open_json(GIT_JSON_NAME)
-    if arg == "*":
-        states = [States.NEW, States.MODIFIED]
-        for state in states:
-            files = json_obj.get(state)
-            files = {k: v for k, v in files.items()}
+    states = [States.NEW, States.MODIFIED]
+    found = False
+    for state in states:
+        files = json_obj.get(state)
+        files = {k: v for k, v in files.items()}
+        if arg == "*":
             for file_name, file_hash in files.items():
                 del json_obj[state][file_name]
                 json_obj[States.STAGED].update({file_name: file_hash})
-    else:
-        state = States.NEW
-        files = json_obj.get(state)
-        files = {k: v for k, v in files.items()}
-        if arg not in files:
-            print(f"there is no file named {arg}")
-            return
-        file_hash = files.get(arg)
-        del json_obj[state][arg]
-        json_obj[States.STAGED].update({arg: file_hash})
+        elif arg in files:
+            file_hash = files.get(arg)
+            del json_obj[state][arg]
+            json_obj[States.STAGED].update({arg: file_hash})
+            found = True
+    if not found and arg != "*":
+        print(f"there is no file named {arg}")
+        return
     update_json(json_obj, json_file)
 
 
